@@ -1,13 +1,9 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   copyright (C) 2002    Oliver Kellogg <okellogg@users.sourceforge.net> *
- *   copyright (C) 2003-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+
+    SPDX-FileCopyrightText: 2002 Oliver Kellogg <okellogg@users.sourceforge.net>
+    SPDX-FileCopyrightText: 2003-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 #include "adawriter.h"
 
@@ -25,8 +21,8 @@
 #include "operation.h"
 #include "template.h"
 
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <KLocalizedString>
+#include <KMessageBox>
 
 #include <QFile>
 #include <QRegExp>
@@ -120,12 +116,12 @@ QString AdaWriter::packageName(UMLPackage *p)
     QString retval;
 
     if (umlPkg == UMLApp::app()->document()->rootFolder(Uml::ModelType::Logical))
-        umlPkg = NULL;
+        umlPkg = 0;
 
-    UMLClassifier *c = dynamic_cast<UMLClassifier*>(p);
-    if (umlPkg == NULL) {
+    UMLClassifier *c = p->asUMLClassifier();
+    if (umlPkg == 0) {
         retval = className;
-        if (c == NULL || !isOOClass(c))
+        if (c == 0 || !isOOClass(c))
             retval.append(defaultPackageSuffix);
     } else {
         retval = umlPkg->fullyQualifiedName(QLatin1String("."));
@@ -145,8 +141,8 @@ void AdaWriter::computeAssocTypeAndRole(UMLClassifier *c,
                                         UMLAssociation *a,
                                         QString& typeName, QString& roleName)
 {
-    UMLClassifier* assocEnd = dynamic_cast<UMLClassifier*>(a->getObject(Uml::RoleType::B));
-    if (assocEnd == NULL)
+    UMLClassifier* assocEnd = a->getObject(Uml::RoleType::B)->asUMLClassifier();
+    if (assocEnd == 0)
         return;
     const Uml::AssociationType::Enum assocType = a->getAssocType();
     if (assocType != Uml::AssociationType::Aggregation && assocType != Uml::AssociationType::Composition)
@@ -177,7 +173,7 @@ void AdaWriter::computeAssocTypeAndRole(UMLClassifier *c,
 void AdaWriter::declareClass(UMLClassifier *c, QTextStream &ada)
 {
     UMLClassifierList superclasses = c->getSuperClasses();
-    UMLClassifier *firstSuperClass = NULL;
+    UMLClassifier *firstSuperClass = 0;
     if (!superclasses.isEmpty()) {
         foreach (UMLClassifier* super, superclasses) {
             if (!super->isInterface()) {
@@ -185,7 +181,7 @@ void AdaWriter::declareClass(UMLClassifier *c, QTextStream &ada)
                 break;
             }
         }
-        if (firstSuperClass == NULL)
+        if (firstSuperClass == 0)
             firstSuperClass = superclasses.first();
     }
     const QString name = className(c);
@@ -230,7 +226,7 @@ void AdaWriter::writeClass(UMLClassifier *c)
         return;
     }
 
-    QFile *file = NULL;
+    QFile *file = 0;
     bool isNewFile = false;
     PackageFileMap::iterator it = m_pkgsGenerated.find(pkg);
     if (it != m_pkgsGenerated.end()) {
@@ -264,7 +260,7 @@ void AdaWriter::writeClass(UMLClassifier *c)
         findObjectsRelated(c, imports);
         if (imports.count()) {
             foreach (UMLPackage* con, imports) {
-                if (con->baseType() == UMLObject::ot_Datatype)
+                if (con->isUMLDatatype())
                     continue;
                 QString pkgDep = packageName(con);
                 if (pkgDep != pkg)
@@ -287,12 +283,12 @@ void AdaWriter::writeClass(UMLClassifier *c)
                 } else {
                     // Check whether it's a data type.
                     UMLClassifier *typeObj = t->getType();
-                    if (typeObj == NULL) {
+                    if (typeObj == 0) {
                         uError() << "template_param " << typeName << ": typeObj is NULL";
                         ada << indent() << "type " << formalName << " is new " << typeName
                             << " with private;  -- CHECK: codegen error"
                             << m_endl;
-                    } else if (typeObj->baseType() == UMLObject::ot_Datatype) {
+                    } else if (typeObj->isUMLDatatype()) {
                         ada << indent() << formalName << " : " << typeName << ";"
                             << m_endl;
                     } else {
@@ -309,7 +305,7 @@ void AdaWriter::writeClass(UMLClassifier *c)
     }
 
     if (c->baseType() == UMLObject::ot_Enum) {
-        UMLEnum *ue = static_cast<UMLEnum*>(c);
+        UMLEnum *ue = c->asUMLEnum();
         UMLClassifierListItemList litList = ue->getFilteredList(UMLObject::ot_EnumLiteral);
         uint i = 0;
         ada << indent() << "type " << classname << " is (" << m_endl;
@@ -458,7 +454,7 @@ void AdaWriter::writeOperation(UMLOperation *op, QTextStream &ada, bool is_comme
     ada << cleanName(op->name()) << " ";
     if (! (op->isStatic() && atl.count() == 0))
         ada << "(";
-    UMLClassifier *parentClassifier = static_cast<UMLClassifier*>(op->umlPackage());
+    UMLClassifier *parentClassifier = op->umlParent()->asUMLClassifier();
     if (! op->isStatic()) {
         ada << "Self : access " << className(parentClassifier);
         if (atl.count())
@@ -712,11 +708,11 @@ void AdaWriter::finalizeRun()
                 if (forceSections() || atl.count()) {
                     ada << indent() << "-- Attributes:" << m_endl;
                     foreach (UMLAttribute* at, atl) {
-                        if (at->isStatic())
+                        if (!at || at->isStatic())
                             continue;
                         ada << indent() << cleanName(at->name()) << " : "
                         << at->getTypeName();
-                        if (at && ! at->getInitialValue().isEmpty() && ! at->getInitialValue().toLatin1().isEmpty())
+                        if (!at->getInitialValue().isEmpty() && !at->getInitialValue().toLatin1().isEmpty())
                             ada << " := " << at->getInitialValue();
                         ada << ";" << m_endl;
                     }
@@ -787,4 +783,3 @@ void AdaWriter::finalizeRun()
 }
 
 
-#include "adawriter.moc"
