@@ -1,12 +1,7 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *  copyright (C) 2002-2014                                                *
- *  Umbrello UML Modeller Authors <umbrello-devel@kde.org>                 *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2002-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 #include "mysqlwriter.h"
 
@@ -16,7 +11,7 @@
 #include "umlclassifierlistitemlist.h"
 #include "umlentityattributelist.h"
 
-#include <klocale.h>
+#include <KLocalizedString>
 
 #include <QList>
 #include <QTextStream>
@@ -88,12 +83,12 @@ void MySQLWriter::printForeignKeyConstraints(QTextStream& sql, UMLClassifierList
     // we need to create an index on the referenced attributes before we can create a foreign key constraint in MySQL
 
     foreach(UMLClassifierListItem* cli, constrList) {
-        UMLForeignKeyConstraint* fkc = static_cast<UMLForeignKeyConstraint*>(cli);
+        UMLForeignKeyConstraint* fkc = cli->asUMLForeignKeyConstraint();
 
         QMap<UMLEntityAttribute*, UMLEntityAttribute*> attributeMap = fkc->getEntityAttributePairs();
 
-        // get the referenced attributes
-        QList<UMLEntityAttribute*> eaList = attributeMap.values();
+        // get the attributes
+        QList<UMLEntityAttribute*> eaList = attributeMap.keys();
 
         // convert to UMLEntityAttributeList
         UMLEntityAttributeList refAttList;
@@ -102,7 +97,7 @@ void MySQLWriter::printForeignKeyConstraints(QTextStream& sql, UMLClassifierList
         }
 
         // create an index on them
-        SQLWriter::printIndex(sql, fkc->getReferencedEntity(), refAttList);
+        SQLWriter::printIndex(sql, m_pEntity, refAttList);
     }
 
     SQLWriter::printForeignKeyConstraints(sql, constrList);
@@ -118,7 +113,7 @@ void MySQLWriter::printAutoIncrements(QTextStream& sql, const UMLEntityAttribute
     // and that attribute should have an index on it :/
 
     // get the first attribute of list with auto increment
-    UMLEntityAttribute* autoIncrementEntAtt = NULL;
+    UMLEntityAttribute* autoIncrementEntAtt = 0;
     foreach(UMLEntityAttribute* ea, entAttList) {
        if (ea->getAutoIncrement()) {
            autoIncrementEntAtt = ea;
@@ -126,7 +121,7 @@ void MySQLWriter::printAutoIncrements(QTextStream& sql, const UMLEntityAttribute
        }
     }
 
-    if (autoIncrementEntAtt == NULL) {
+    if (autoIncrementEntAtt == 0) {
         return;
     }
 
@@ -167,4 +162,3 @@ void MySQLWriter::printCheckConstraints(QTextStream& sql, UMLClassifierListItemL
     SQLWriter::printCheckConstraints(sql, constrList);
 }
 
-#include "mysqlwriter.moc"
